@@ -18,7 +18,7 @@
  */
 
 #include "aclmanager.h"
-#include "helper_p.h"
+
 #include "pimcommonakonadi_debug.h"
 #include "aclentrydialog_p.h"
 #include "aclutils_p.h"
@@ -30,6 +30,7 @@
 #include <CollectionModifyJob>
 #include <Akonadi/Contact/ContactGroupExpandJob>
 #include <Akonadi/Contact/ContactGroupSearchJob>
+#include <AkonadiCore/ServerManager>
 #include "aclmodifyjob.h"
 #include <KEmailAddress>
 
@@ -56,7 +57,7 @@ public:
     {
     }
 
-    QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const Q_DECL_OVERRIDE
+    QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const override
     {
         if (index.row() < 0 || index.row() >= mRights.count()) {
             return QVariant();
@@ -79,7 +80,7 @@ public:
 
     }
 
-    bool setData(const QModelIndex &index, const QVariant &value, int role = Qt::EditRole) Q_DECL_OVERRIDE {
+    bool setData(const QModelIndex &index, const QVariant &value, int role = Qt::EditRole) override {
         if (index.row() < 0 || index.row() >= mRights.count())
         {
             return false;
@@ -106,7 +107,7 @@ public:
         return false;
     }
 
-    int rowCount(const QModelIndex &parent = QModelIndex()) const Q_DECL_OVERRIDE
+    int rowCount(const QModelIndex &parent = QModelIndex()) const override
     {
         if (parent.isValid()) {
             return 0;
@@ -143,7 +144,7 @@ public:
     }
 
 protected:
-    bool insertRows(int row, int count, const QModelIndex &parent = QModelIndex()) Q_DECL_OVERRIDE {
+    bool insertRows(int row, int count, const QModelIndex &parent = QModelIndex()) override {
         beginInsertRows(parent, row, row + count - 1);
         for (int i = 0; i < count; ++i)
         {
@@ -154,7 +155,7 @@ protected:
         return true;
     }
 
-    bool removeRows(int row, int count, const QModelIndex &parent = QModelIndex()) Q_DECL_OVERRIDE {
+    bool removeRows(int row, int count, const QModelIndex &parent = QModelIndex()) override {
         beginRemoveRows(parent, row, row + count - 1);
         for (int i = 0; i < count; ++i)
         {
@@ -303,7 +304,11 @@ public:
 
         QString resource = collection.resource();
         if (resource.contains(QStringLiteral("akonadi_kolabproxy_resource"))) {
-            QDBusInterface interface(QStringLiteral("org.freedesktop.Akonadi.Agent.akonadi_kolabproxy_resource"), QStringLiteral("/KolabProxy"));
+            QString basename(QStringLiteral("org.freedesktop.Akonadi.Agent.akonadi_kolabproxy_resource"));
+            if (Akonadi::ServerManager::hasInstanceIdentifier()) {
+                basename += QLatin1Char('.') + Akonadi::ServerManager::instanceIdentifier();
+            }
+            QDBusInterface interface(basename, QStringLiteral("/KolabProxy"));
             if (interface.isValid()) {
                 QDBusReply<QString> reply = interface.call(QStringLiteral("imapResourceForCollection"), collection.remoteId().toLongLong());
                 if (reply.isValid()) {
